#[non_exhaustive]pub struct ListNotebookSessionsInput {
pub notebook_id: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notebook_id: Option<String>The ID of the notebook to list sessions for.
max_results: Option<i32>The maximum number of notebook sessions to return.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListNotebookSessionsInput
impl ListNotebookSessionsInput
Sourcepub fn notebook_id(&self) -> Option<&str>
pub fn notebook_id(&self) -> Option<&str>
The ID of the notebook to list sessions for.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of notebook sessions to return.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListNotebookSessionsInput
impl ListNotebookSessionsInput
Sourcepub fn builder() -> ListNotebookSessionsInputBuilder
pub fn builder() -> ListNotebookSessionsInputBuilder
Creates a new builder-style object to manufacture ListNotebookSessionsInput.